import Vue from 'vue'
import VueI18n from 'vue-i18n'
import { ANALYTIZE_KEYS } from '~/common/c.js'
import {
  isObjectEmpty,
  MyCookie,
  getPageCode,
  parseEncodeURIComponent
} from '~/common/utils.js'

Vue.use(VueI18n)

export default ({ app, store, route, query }) => {
  // Set i18n instance on app
  // This way we can use it in middleware and pages asyncData/fetch
  app.i18n = new VueI18n({
    locale: store.state.locale,
    fallbackLocale: 'cn',
    messages: {
      cn: require('~/locales/cn.json'),
      en: require('~/locales/en.json')
    }
  })
  app.i18n.path = link => {
    // if (app.i18n.locale === app.i18n.fallbackLocale) {
    //   return `/${link}`
    // }
    return `/${app.i18n.locale}/${link}`
  }
  if (process.client) {
    let originUrl = MyCookie.getCookie('originUrl')
    if (!originUrl) {
      MyCookie.setCookie(
        'originUrl',
        encodeURIComponent(parseEncodeURIComponent(window.location.href)),
        7,
        true
      )
      let pageCode = getPageCode(window.location.href)
      MyCookie.setCookie('originUrlCode', pageCode, 7, true)
    }
    let analytizeQuery = {}
    const queryKeys = Object.keys(query)
    queryKeys.forEach(key => {
      ANALYTIZE_KEYS.some(k => {
        if (key.toLowerCase() === k.toLowerCase()) {
          analytizeQuery[k] = parseEncodeURIComponent(query[key])
          return true
        }
      })
    })
    if (!isObjectEmpty(analytizeQuery)) {
      store.commit('SET_ANALYTIZE_QUERY', analytizeQuery)
      MyCookie.setCookie(
        'analytizeQuery',
        encodeURIComponent(JSON.stringify(analytizeQuery)),
        7,
        true
      )
      MyCookie.setCookie(
        'originUrl',
        encodeURIComponent(parseEncodeURIComponent(window.location.href)),
        7,
        true
      )
      let pageCode = getPageCode(window.location.href)
      MyCookie.setCookie('originUrlCode', pageCode, 7, true)
    }
    const { shareCrmUid, shareUid } = query
    if (shareCrmUid) {
      MyCookie.setCookie('shareCrmUid', shareCrmUid, 7, true)
    }
    if (shareUid) {
      MyCookie.setCookie('shareUid', shareUid, 7, true)
    }
    const rfr = window.document.referrer
    if (rfr) {
      let twoSc = ''
      if (rfr.indexOf('baidu.com/') !== -1) {
        twoSc = 'nature_baidu'
      } else if (rfr.indexOf('google.com/') !== -1) {
        twoSc = 'nature_google'
      } else if (rfr.indexOf('sogou.com/') !== -1) {
        twoSc = 'nature_sougou'
      } else if (rfr.indexOf('sm.cn/') !== -1) {
        twoSc = 'nature_sm'
      } else if (rfr.indexOf('bing.com/') !== -1) {
        twoSc = 'nature_bing'
      } else if (rfr.indexOf('so.com/') !== -1) {
        twoSc = 'nature_360'
      }
      if (twoSc) {
        MyCookie.setCookie('twoSc', twoSc, 7, true)
      }
    } else {
      MyCookie.deleteCookie('twoSc')
    }
  }
}
